Accessibility Statement - ServiceNow
[ Skip to Main Content ](https://www.servicenow.com/accessibility-statement.html#main-content)
[ ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-header-logo.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-logo-icon.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-header-logo-white.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-logo-icon-white.svg) ](https://www.servicenow.com/)
  * MyNow
  * Products
  * Industries
  * Learning
  * Support
  * Partners
  * Company


* * *
  * ![Select your country](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/language-selector-light.svg)United States - Global Main menu
  * [ Get Started ](https://www.servicenow.com/contact-us.html)
  * Sales
[ +1 (844) 863-1987 ](tel:+1%20\(844\)%20863-1987)
  * [ View a Demo ](https://www.servicenow.com/lpdem/demonow-all.html)


Search
![Clear Search](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/close-icon.svg)
Clear Search
![Search across ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/search-icon.svg)
![Close Search](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/close-icon.svg)
![Select your country](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/language-selector-light.svg)
Americas
  * [United States - Global](https://www.servicenow.com/accessibility-statement.html)
  * [Brasil - Português](https://www.servicenow.com/br/accessibility-statement.html)
  * [Canada - Français](https://www.servicenow.com/fr-ca/accessibility-statement.html)
  * [América Latina - Español](https://www.servicenow.com/latam/accessibility-statement.html)


Asia, Pacific, and Japan
  * [日本 - 日本語](https://www.servicenow.com/jp/accessibility-statement.html)
  * [한국 - 한국어](https://www.servicenow.com/kr/accessibility-statement.html)
  * [Australia/NZ - English](https://www.servicenow.com/au/accessibility-statement.html)
  * [India - English](https://www.servicenow.com/in/accessibility-statement.html)


Europe, Middle East, and Africa
  * [United Kingdom - English](https://www.servicenow.com/uk/accessibility-statement.html)
  * [DACH - Deutsch](https://www.servicenow.com/de/accessibility-statement.html)
  * [France - Français](https://www.servicenow.com/fr/accessibility-statement.html)
  * [Nederland - Nederlands](https://www.servicenow.com/nl/accessibility-statement.html)
  * [España - Español](https://www.servicenow.com/es/accessibility-statement.html)
  * [Italia - Italiano](https://www.servicenow.com/it/accessibility-statement.html)


* * *
Sales
[ +1 (844) 863-1987 ](tel:+1%20\(844\)%20863-1987)
[ Get Started ](https://www.servicenow.com/contact-us.html)
MyNow
Explore MyNow, your personalized experience for quick access to your workflows, to-do lists, and AI guided recommendations.
[ Home ](https://mynow.servicenow.com/now/mynow/my-home/home)
Products
  * Featured products
  * ServiceNow AI Platform
  * Demo Library


Solutions
  * IT
  * CRM
  * Risk and Security
  * Employee Experience
  * App Development
  * [ ](https://www.servicenow.com/products-by-category.html)


Featured products
Products
Unite people, processes, and systems with AI-powered products for all your workflows.
[ See All Products ](https://www.servicenow.com/products-by-category.html)
Featured products
  * ### [AI Agents Take action with autonomous AI agents that work for you. ](https://www.servicenow.com/products/ai-agents.html)
  * ### [IT Service Management Transform service management for productivity and ROI. ](https://www.servicenow.com/products/itsm.html)
  * ### [ServiceNow AI Control Tower Connect strategy, governance, management, and performance for all your AI across the enterprise. ](https://www.servicenow.com/products/ai-control-tower.html)
  * ### [IT Operations Management Deliver proactive digital operations with AIOps. ](https://www.servicenow.com/products/it-operations-management.html)
  * ### [Customer Service Management Empower self-service, boost agent productivity, and speed up resolution. ](https://www.servicenow.com/products/customer-service-management.html)
  * ### [Strategic Portfolio Management Gain insights to move from strategy to business outcomes. ](https://www.servicenow.com/products/strategic-portfolio-management.html)
  * ### [IT Asset Management Improve technology use and spend over the IT asset lifecycle. ](https://www.servicenow.com/products/it-asset-management.html)
  * ### [Governance, Risk, and Compliance Enable an integrated approach that builds operational resilience and mitigates risk. ](https://www.servicenow.com/products/governance-risk-and-compliance.html)
  * ### [Security Operations Defend against security threats and attacks. ](https://www.servicenow.com/products/security-operations.html)
  * ### [Field Service Management Reduce field service costs and improve efficiency. ](https://www.servicenow.com/products/field-service-management.html)
  * ### [HR Service Delivery Give employees instant answers, guidance, and fast issue resolution. ](https://www.servicenow.com/products/hr-service-delivery.html)
  * ### [EmployeeWorks Stop chasing what other AI tools should have finished. ](https://www.servicenow.com/products/employeeworks.html)


### Meet the Autonomous Workforce
The Autonomous Workforce is more than just isolated tasks. These AI specialists are assigned to roles, with business context and permissions to handle complex workflows end-to-end.
[ Learn More ](https://www.servicenow.com/platform/autonomous-workforce.html)
ServiceNow AI Platform
One platform, ready for anything
AI, data, and workflows—working together on one platform. Only ServiceNow makes it this simple at scale.
[ Explore AI Platform ](https://www.servicenow.com/now-platform.html)
  * ### [AI Put AI to work across your business with our single, intelligent platform. ](https://www.servicenow.com/ai.html)
  * ### [Data Power all your workflows, AI, and analytics with real-time access to data from any source. ](https://www.servicenow.com/now-platform/workflow-data-fabric.html)
  * ### [Workflows Automate workflows to lower costs and raise productivity. ](https://www.servicenow.com/now-platform/workflow-automation.html)
  * ### [AI Experience Bring AI directly into the flow of work with the UI for Enterprise AI. ](https://www.servicenow.com/now-platform/ai-experience.html)
  * ### [RaptorDB Unify data and analytics on the ServiceNow AI Platform for ultra-fast workflow performance at scale. ](https://www.servicenow.com/products/raptordb.html)
  * ### [Infrastructure Deploy, automate, and scale with trusted and flexible cloud-based infrastructure options built to make work flow. ](https://www.servicenow.com/now-platform/infrastructure.html)
  * ### [AI Agents AI Agents Take action with autonomous AI agents that work for you. ](https://www.servicenow.com/products/ai-agents.html)
  * ### [ServiceNow AI Control Tower Connect strategy, governance, management, and performance for all your AI across the enterprise. ](https://www.servicenow.com/products/ai-control-tower.html)
  * ### [Security Protect sensitive data and increase security, privacy, and compliance across the enterprise. ](https://www.servicenow.com/products/vault.html)
  * ### [App Engine Build apps that automate manual work and modernize legacy processes. ](https://www.servicenow.com/products/now-platform-app-engine.html)
  * ### [ServiceNow Store Do more with the ServiceNow AI Platform. Find hundreds of certified, ready to use applications. ](https://store.servicenow.com/sn_appstore_store.do#!/store/home)
  * ### [Responsible AI Rely on ServiceNow for AI that’s human-centered, inclusive, transparent, and accountable.  ](https://www.servicenow.com/now-platform/responsible-ai.html)


Demo Library
Demo Library
Watch and learn. Our product and solutions experts offer demo options for everyone, at every skill level.
[ Explore Demo Library ](https://www.servicenow.com/demo/demonow.html)
Featured demos
  * [ ![Provide better experiences](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/provide-better-experiences.jpg) Provide better experiences Learn how you can use GenAI to equip customers and employees with self-service for requests. (3:17) ](https://www.servicenow.com/demo/demonow-detail.html?videoid=put-ai-to-work-with-now-assist-for-customers-and-employees)
  * [ ![Resolve issues faster](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/resolve-issues-faster.jpg) Resolve issues faster Find out how your business can reduce manual work and help agents resolve cases faster. (4:08) ](https://www.servicenow.com/demo/demonow-detail.html?videoid=put-ai-to-work-with-now-assist-for-agents)
  * [ ![Create and automate workflows](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/create-automate-workflows.jpg) Create and automate workflows See how to simplify the way workflows are built and custom code is developed. (4:30) ](https://www.servicenow.com/demo/demonow-detail.html?videoid=put-ai-to-work-with-now-assist-for-developers-and-admins)


Solutions
IT
IT
Anticipate needs with efficient IT and digital operations.
[ Explore Solution ](https://www.servicenow.com/solutions/enterprise-it.html)
Related Products
  * ### [Enterprise Architecture Build a bridge between business processes and IT architecture. ](https://www.servicenow.com/products/enterprise-architecture.html)
  * ### [Service Operations Workspace Predict, prevent, and resolve incidents proactively from a single workspace. ](https://www.servicenow.com/products/service-operations-workspace.html)
  * ### [Cloud Governance Suite Automate cloud governance for better compliance, security, and costs. ](https://www.servicenow.com/solutions/cloud-transformation.html)
  * ### [Operational Technology Management Protect your OT environment and improve uptime. ](https://www.servicenow.com/products/operational-technology-management.html)
  * ### [IT Asset Management Control costs and minimize risks across the IT asset lifecycle. ](https://www.servicenow.com/products/it-asset-management.html)
  * ### [IT Operations Management Deliver proactive digital operations with AIOps. ](https://www.servicenow.com/products/it-operations-management.html)
  * ### [IT Service Management Transform service management to boost productivity and maximize ROI. ](https://www.servicenow.com/products/itsm.html)
  * ### [ServiceNow Cloud Observability Gain insights to detect and respond to changes in cloud-native apps. ](https://www.servicenow.com/products/observability.html)
  * ### [Strategic Portfolio Management Gain insights to move from strategy to business outcomes. ](https://www.servicenow.com/products/strategic-portfolio-management.html)
  * ### [Digital End-user Experience Improve your employees' endpoint technology experience.  ](https://www.servicenow.com/products/digital-user-experience.html)


CRM
CRM
Deliver a seamless, personalized end-to-end customer experience.
[ Explore Solution ](https://www.servicenow.com/solutions/crm.html)
Related Products
  * ### [Customer Service Management Empower self-service, boost agent productivity, and speed up resolution. ](https://www.servicenow.com/products/customer-service-management.html)
  * ### [Field Service Management Optimize scheduling, empower technicians, and reduce unneeded visits. ](https://www.servicenow.com/products/field-service-management.html)
  * ### [Sales and Order Management Accelerate the lead-to-cash cycle and boost revenue. ](https://www.servicenow.com/products/sales-management.html)
  * ### [Configure, Price, Quote Use AI to simplify and accelerate sales across all channels. ](https://www.servicenow.com/products/cpq.html)
  * ### [Financial Services Operations Provide resilient financial services operations for enhanced experiences. ](https://www.servicenow.com/products/financial-services-operations.html)
  * ### [Healthcare and Life Sciences Service Management Create consumer-grade healthcare experiences and improve operational performance. ](https://www.servicenow.com/products/healthcare-life-sciences.html)
  * ### [Sales and Order Management for Technology Providers Fuel XaaS revenue with AI-powered experiences across sales and order lifecycles. ](https://www.servicenow.com/products/order-management-tech-providers.html)
  * ### [Sales and Order Management for Telecommunications Grow revenue with AI-powered experiences across sales, fulfillment, and services. ](https://www.servicenow.com/products/telecom-order-management.html)
  * ### [Public Sector Digital Services Modernize and speed up the delivery of government services. ](https://www.servicenow.com/products/public-sector-digital-services.html)
  * ### [Telecommunications Service Management Unlock growth with AI-powered experiences across customer service and network operations. ](https://www.servicenow.com/products/telecommunications-service-management.html)
  * ### [Technology Provider Service Management Promote speed and growth for your XaaS business with AI-powered experiences. ](https://www.servicenow.com/products/technology-provider-service-management.html)


Risk and Security
Risk and Security
Minimize the risk, impact, and cost of securing your business.
[ Explore Solution ](https://www.servicenow.com/solutions/security.html)
Related Products
  * ### [Security Operations Mount an effective defense against security threats and attacks. ](https://www.servicenow.com/products/security-operations.html)
  * ### [Security Incident Response Respond fast to evolving threats while optimizing security operations. ](https://www.servicenow.com/products/security-incident-response.html)
  * ### [Vulnerability Response Identify, prioritize, and remediate vulnerabilities across the business. ](https://www.servicenow.com/products/vulnerability-response.html)
  * ### [Threat Intelligence Security Center Gain advanced threat hunting, modeling, and analysis on the ServiceNow AI Platform. ](https://www.servicenow.com/products/threat-intelligence-security-center.html)
  * ### [Integrated Risk Management Make risk-informed decisions while improving efficiency and resilience. ](https://www.servicenow.com/products/integrated-risk-management.html)
  * ### [Third-party Risk Management Reduce third-party risk while improving resilience and compliance. ](https://www.servicenow.com/products/third-party-risk-management.html)
  * ### [Security Posture Control Manage the security of enterprise assets on premises and in the cloud. ](https://www.servicenow.com/products/security-posture-control.html)
  * ### [Privacy Management Manage data privacy in real time as part of a holistic enterprise risk program. ](https://www.servicenow.com/products/privacy-management.html)


Employee Experience
Employee Experience
Automate the busywork, so that you can unleash your talent on the big work.
[ Explore Solution ](https://www.servicenow.com/solutions/employee-experience.html)
Related Products
  * ### [HR Service Delivery Give employees instant answers, guidance, and fast issue resolution. ](https://www.servicenow.com/products/hr-service-delivery.html)
  * ### [Talent Development Make AI and skills-driven talent planning and development decisions. ](https://www.servicenow.com/products/talent-development.html)
  * ### [Legal Service Delivery Modernize operations to make faster decisions and grow productivity. ](https://www.servicenow.com/products/legal-service-delivery.html)
  * ### [Workplace Service Delivery Automate desk bookings, manage facilities, and optimize operations. ](https://www.servicenow.com/products/workplace-service-delivery.html)
  * ### [Accounts Payable Operations Automate invoice ingestion and pay suppliers accurately. ](https://www.servicenow.com/products/accounts-payable.html)
  * ### [Sourcing and Procurement Operations Deploy easy-to-follow procurement processes. ](https://www.servicenow.com/products/procurement-service-management.html)
  * ### [Supplier Lifecycle Operations Streamline supplier onboarding, collaboration, and performance management. ](https://www.servicenow.com/products/supplier-lifecycle-management.html)
  * ### [EmployeeWorks Stop chasing what other AI tools should have finished. ](https://www.servicenow.com/products/employeeworks.html)


App Development
App Development
Build custom apps fast while enhancing developer and business expert productivity.
[ Explore Solution ](https://www.servicenow.com/solutions/application-development.html)
Related Products
  * ### [App Engine Build apps that automate manual work and modernize legacy processes. ](https://www.servicenow.com/products/now-platform-app-engine.html)
  * ### [Integration Hub Reduce cost and complexity for ServiceNow integrations. ](https://www.servicenow.com/products/integration-hub.html)


[ ](https://www.servicenow.com/products-by-category.html)
Industries
Browse solutions to help you solve the complex business challenges unique to your industry.
[ Learn More ](https://www.servicenow.com/industries.html)
  * ### [Automotive Put your automotive operations in overdrive with a single AI platform. ](https://www.servicenow.com/industries/automotive.html)
  * ### [Banking Future-proof your bank with one AI platform. ](https://www.servicenow.com/industries/banking.html)
  * ### [Consumer Packaged Goods Power your product growth and efficiency with a single AI platform. ](https://www.servicenow.com/industries/consumer-packaged-goods.html)
  * ### [Healthcare Fuel efficiency, reduce costs, and deliver quality care with a single AI platform. ](https://www.servicenow.com/industries/healthcare.html)
  * ### [Insurance Be the trusted carrier of choice with one AI platform. ](https://www.servicenow.com/industries/insurance.html)
  * ### [Life Sciences Accelerate innovation, in and out of the lab, with one AI-powered platform. ](https://www.servicenow.com/industries/life-sciences.html)
  * ### [Manufacturing Drive manufacturing efficiency with one AI platform. ](https://www.servicenow.com/industries/manufacturing.html)
  * ### [Nonprofit Learn how to do more with less while making your nonprofit organization more agile and effective. ](https://www.servicenow.com/solutions/industry/non-profit.html)
  * ### [National Government Deliver secure experiences for civilian, defense, and intelligence IT workflows. ](https://www.servicenow.com/industries/government.html)
  * ### [Retail Enhance retail experiences with AI-powered insights on a single AI platform. ](https://www.servicenow.com/industries/retail.html)
  * ### [Technology Providers Reimagine your XaaS lifecycle with a single AI platform. ](https://www.servicenow.com/industries/technology-providers.html)
  * ### [Telecom Grow revenue, automate operations, and manage infrastructure on one AI platform. ](https://www.servicenow.com/industries/telecom.html)


Learning
  * ServiceNow University
  * Community
  * Developer Resources
  * Events
  * Customer Stories
  * Blog


ServiceNow University
ServiceNow University
Discover a playground for learning, designed to help develop the skills you need for an AI-driven world.
[ Start Learning ](https://learning.servicenow.com/now/lxp/home)
  * ### [Training & Certification Explore ServiceNow certifications, career journeys, and expert programs—all designed to build your skills and elevate your career. ](https://www.servicenow.com/university/training-and-certification.html)
  * ### [Skill Your Team Upskill your teams with scalable, role-based training designed to help you reach your digital transformation goals faster. ](https://www.servicenow.com/university/skill-your-team.html)
  * ### [Skilling Programs Explore skilling programs at ServiceNow University, including RiseUp and partnerships that develop ServiceNow-skilled talent to meet rising ecosystem demands. ](https://www.servicenow.com/university/skilling-programs.html)


Community
Community
Learn from ServiceNow experts and engage in discussions with industry peers.
[ Visit Community ](https://www.servicenow.com/community)
  * ### [Product hubs Find the resources, tools, and guidance you need for any ServiceNow product. ](https://www.servicenow.com/community/products/ct-p/product-discussions)
  * ### [ServiceNow user groups Join a user group in person or online to expand your network and knowledge. ](https://www.servicenow.com/community/servicenow-user-groups-snugs/ct-p/servicenow-user-groups-snugs)
  * ### [Developer forum Connect with other developers to ask questions, offer solutions, and build together. ](https://www.servicenow.com/community/developer/ct-p/Developer)
  * ### [Community events Find live events for the ServiceNow community online or in person near you. ](https://www.servicenow.com/community/events/ct-p/TopLevel_Events)
  * ### [Community Central From updates to best practices, find all things community related. ](https://www.servicenow.com/community/community-central/ct-p/community-central)
  * ### [Join the community Become a member of our vibrant ServiceNow community. ](https://www.servicenow.com/community/community-central/ct-p/community-central)


Developer Resources
Developer resources
Get your team building apps fast with tools and personal developer instances.
[ Explore Resources ](https://developer.servicenow.com/dev.do)
  * ### [Learn Browse learning plans and courses that teach you how to build apps to tackle your company's business needs. ](https://developer.servicenow.com/dev.do#!/learn)
  * ### [Reference documentation Find APIs, libraries, and supplemental materials for working with the ServiceNow AI Platform. ](https://developer.servicenow.com/dev.do#!/reference)
  * ### [Guides Read technology overviews and recommendations for innovating on the ServiceNow AI Platform. ](https://developer.servicenow.com/dev.do#!/guides)
  * ### [Connect Meet fellow creators and gain insights from the community. ](https://developer.servicenow.com/dev.do#!/connect)
  * ### [Design Find components, patterns, and resources to help you start designing experiences on the ServiceNow AI Platform. ](https://horizon.servicenow.com/)


Events
Events
Join us at an event and learn how the world works with ServiceNow.
[ Find Your Event ](https://www.servicenow.com/events.html)
  * ### [Knowledge 2026 Join us May 5-7 at Knowledge, where you and AI get to work.  ](https://www.servicenow.com/events/knowledge.html)
  * ### [World Forum 2026 Check out 2026 dates and locations, and discover how you can put AI to work in a city near you.  ](https://www.servicenow.com/events/world-forum.html)
  * ### [Webinars Broaden your knowledge by registering for live and on demand ServiceNow webinars. ](https://www.servicenow.com/events/on-demand-webinars.html)
  * ### [Community events Find live events for the ServiceNow community happening near you. ](https://www.servicenow.com/community/events/ct-p/TopLevel_Events)


![Two people at the Knowledge conference taking a picture.](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/images/company-events/knowledge/26/background/k26-promo-menu.lg.png)
### Registration is open for Knowledge 2026
Join us for the AI event that can change everything. Act now to save big. Come for the wow, leave with the know-how.
[ Register Now ](https://www.servicenow.com/events/knowledge.html?referenceSource=dotcom:k26:earlybird:nav:reg)
Customer Stories
Customer stories
Find out how businesses like yours rely on ServiceNow to make the world work.
[ Read Stories ](https://www.servicenow.com/customers.html)
  * ### [AI Agent Stories Learn how ServiceNow customers are putting AI to work. ](https://www.servicenow.com/customers.html?page=1&products-category=servicenow%3Aproducts%2Fai-agents)
  * ### [HR Stories See how organizations are improving self-service and delivering outstanding employee experiences. ](https://www.servicenow.com/customers.html?page=1&products-category=servicenow%3Aproducts%2Fhr-service-delivery)
  * ### [CRM Stories Discover how businesses enable self-service for customers and reduce resolution time. ](https://www.servicenow.com/customers.html?page=1&solutions-category=servicenow%3Asolutions%2Fcustomer-service)
  * ### [Public Sector/Government Stories Explore ways to streamline operations, engage citizens, and empower employees. ](https://www.servicenow.com/customers.html?page=1&Industry-category=servicenow%3AIndustry%2Fgovernment)
  * ### [Now on Now Hear how ServiceNow uses ServiceNow. ](https://www.servicenow.com/company/how-servicenow-uses-servicenow.html)


![Aston Martin logo](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/digital-graphics/ds-logos/logo-aston-martin-aramco-f1-white.svg)
### Featured customer story
Aston Martin Aramco partners with ServiceNow to boost efficiency and productivity on and off the race track.
[ Read story ](https://www.servicenow.com/customers/f1.html)
Blog
Blog
Find unique perspectives on products, company news, and life at ServiceNow.
[ Read the Latest ](https://www.servicenow.com/blogs)
  * ### [Company news See the latest news and stories about ServiceNow partnerships, technology, and innovation. ](https://www.servicenow.com/blogs/category/company-news)
  * ### [Trends and research Learn what the ServiceNow Research team is exploring to improve AI-powered experiences. ](https://www.servicenow.com/blogs/category/servicenow-research)
  * ### [Product insights Read about the positive impact of ServiceNow products in action. ](https://www.servicenow.com/blogs/category/product-news)


Support
  * Customer Support
  * Documentation
  * Best Practices
  * MyNow
  * Customer Success
  * Platform Releases


Customer Support
Customer Support
Access your instances, manage tasks and explore self-service help all in one place.
  * ### [Community Connect with other customers to share tips, exchange resources, and solve problems together. ](https://www.servicenow.com/community/)
  * ### [Get support Discover answers, troubleshoot issues, and get expert help, all in our support center. ](https://support.servicenow.com/)


Documentation
Documentation
Find answers to your technical questions and learn how to use ServiceNow products.
[ Visit Documentation ](https://www.servicenow.com/docs/)
  * ### [IT Service Management Deliver IT services to your users all through a single cloud-based platform. ](https://servicenow.com/docs/csh?version=latest&topicname=r_ITServiceManagement.html)
  * ### [Customer Service Management Provide customers the ability to communicate and receive support through multiple channels. ](https://servicenow.com/docs/csh?version=latest&topicname=c_CustomerServiceManagement.html)
  * ### [IT Operations Management Get visibility into infrastructure and services, prevent outages, and expand operational agility. ](https://servicenow.com/docs/csh?version=latest&topicname=r_ITOMApplications.html)
  * ### [ServiceNow AI Platform Automate processes and develop, run, and manage applications. ](https://servicenow.com/docs/csh?version=latest&topicname=now-platform-landing.html)


### What’s new in AI experiences
Use AI-based tools to prioritize and automate routine tasks, detect incidents, and surface insights.
[ Start Reading ](https://servicenow.com/docs/csh?version=latest&topicname=ai-products.html)
Best Practices
Best Practices
Accelerate outcomes with expert-curated best practices for the ServiceNow AI Platform.
[ Home ](https://mynow.servicenow.com/now/best-practices/home)
  * ### [ServiceNow AI Platform Automate business processes, streamline app development, and manage digital infrastructure. ](https://mynow.servicenow.com/now/best-practices/collections/now-platform-best-practices)
  * ### [Customer Service Management Deliver exceptional service, empower customers, and enhance their experience. ](https://mynow.servicenow.com/now/best-practices/collections/customer-service-management-best-practices)
  * ### [IT Service Management Streamline IT service delivery, boost productivity, resolve issues, and enhance user satisfaction. ](https://mynow.servicenow.com/now/best-practices/collections/it-service-management-best-practices)
  * ### [Employee Service Management Streamline onboarding, provide HR and IT support, and empower employees with digital workflows. ](https://mynow.servicenow.com/now/best-practices/collections/employee-service-management-best-practices)
  * ### [Telecommunications Service Management Unify telecom operations and deliver proactive care with quality and availability for services. ](https://mynow.servicenow.com/now/best-practices/collections/telecommunications-service-management-best-practices)
  * ### [Governance, Risk, and Compliance Build an integrated risk program, enhance decision-making, and improve performance with automation. ](https://mynow.servicenow.com/now/best-practices/collections/governance-risk-and-compliance-best-practices)
  * ### [Security Operations Accelerate response and strengthen security posture with SecOps workflows. ](https://mynow.servicenow.com/now/best-practices/collections/security-operations-best-practices)


MyNow
MyNow
Explore MyNow, your personalized experience for quick access to your workflows, to-do lists, and AI guided recommendations.
  * ### [Learn More Start your day with MyNow. ](https://www.servicenow.com/mynow.html)


Customer Success
Customer Success
Increase your ROI and get more value from the ServiceNow platform.
  * ### [ServiceNow Impact™ success plans Receive long-term adoption guidance and support with an Impact success plan tailored to you. ](https://www.servicenow.com/impact.html)
  * ### [Services Implement and optimize ServiceNow with expert help from ServiceNow and our partners. ](https://www.servicenow.com/services/expert-services.html)


Platform Releases
ServiceNow Platform Zurich Release
See innovation highlights, get release notes, and start your upgrade to our latest ServiceNow AI Platform software release.
[ Go to Latest Release ](https://www.servicenow.com/now-platform/latest-release.html)
Past Releases
  * ### [Yokohama Put AI innovations to work today. ](https://www.servicenow.com/docs/bundle/yokohama-release-notes/page/release-notes/family-release-notes.html)
  * ### [Xanadu The biggest ServiceNow AI release yet. ](https://www.servicenow.com/docs/bundle/xanadu-release-notes/page/release-notes/family-release-notes.html)
  * ### [Washington D.C. Take work to the next level with smarter, faster, simpler experiences for everyone. ](https://www.servicenow.com/docs/bundle/washingtondc-release-notes/page/release-notes/family-release-notes.html)


Partners
Locate the partner you need, or explore the benefits of partnering with ServiceNow.
[ Learn More ](https://www.servicenow.com/partners.html)
  * ### [Find a partner Connect with a ServiceNow partner to reach your business goals. ](https://www.servicenow.com/partners/partner-finder.html)
  * ### [Become a partner Join our partner ecosystem. Choose the partner paths that best fit your expertise and experience. ](https://www.servicenow.com/partners/become-a-partner.html)
  * ### [Partner awards Meet the global ServiceNow partners leading the way in innovation and value for our customers. ](https://www.servicenow.com/partners/awards.html)
  * ### [Partner portal Find tasks, alerts, and information you need, all in one place. ](https://partnerportal.service-now.com/partnerhome)
  * ### [Partner applications Explore innovative apps that extend and complement the ServiceNow AI Platform. ](https://store.servicenow.com/sn_appstore_store.do#!/store/home?offeredby=partners)


Discover how the world works with ServiceNow
Bring AI Agents to every corner of your business.
[ Learn More ](https://www.servicenow.com/company.html)
  * ### [Careers Make your next career move with the fastest growing enterprise software company. ](https://careers.servicenow.com/careers)
  * ### [Investors Explore investor news and resources. ](https://www.servicenow.com/company/investor-relations.html)
  * ### [ServiceNow AI Research Learn how we keep innovation moving forward through our AI research team, labs, and partnerships. ](https://www.servicenow.com/research/)
  * ### [Leadership Meet the ServiceNow leadership team. ](https://www.servicenow.com/company/leadership.html)
  * ### [Locations See ServiceNow office locations around the world. ](https://www.servicenow.com/company/locations.html)
  * ### [Newsroom ServiceNow is making headlines. Find announcements, media kits, and more. ](https://newsroom.servicenow.com/overview/default.aspx)
  * ### [Analyst Reports Get expert insights from top industry analysts on ServiceNow. ](https://www.servicenow.com/company/analyst-reports.html)
  * ### [Global impact Join us to foster a more sustainable, fair, and ethical world. ](https://www.servicenow.com/company/global-impact.html)
  * ### [Trust and compliance Learn the measures ServiceNow takes to keep your data secure and compliant. ](https://www.servicenow.com/company/trust.html)


![Company Collage](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/company-collage.png)
Sales
[ +1 (844) 863-1987 ](tel:+1%20\(844\)%20863-1987)
* * *
[ View a Demo ](https://www.servicenow.com/lpdem/demonow-all.html)
[ Back ](https://www.servicenow.com/accessibility-statement.html)
Created with Sketch.
#### Sign in with your ServiceNow ID
Get access to the latest tools and exclusive content.
  * Email
  * Show
Password
  * Show
Password
  * Two + 3 = ?
[Forgot your password?](https://www.servicenow.com/accessibility-statement.html)
[Sign In](https://www.servicenow.com/accessibility-statement.html##) Re-Send Verification Email


or
[Get a ServiceNow ID ](https://www.servicenow.com/accessibility-statement.html)
[Different issues? Our FAQ can help. ](https://www.servicenow.com/accessibility-statement.html)
Skip To Try Demo
Created with Sketch.
## Recovery Email
Your account give you access to even more premium content, don't lose access to it. Provide a recovery email below.
  * Secondary E-mail


[TRY DEMO ](https://www.servicenow.com/accessibility-statement.html##)
#  ServiceNow® Accessibility Statement
**Last Updated in January 2026**
###  Table of Contents
  * [Our Dedicated Accessibility Practice](https://www.servicenow.com/accessibility-statement.html#practice)
  * [Accessibility Conformance Reports (ACRs)](https://www.servicenow.com/accessibility-statement.html#acrs)
  * [2025 Accomplishments](https://www.servicenow.com/accessibility-statement.html#two-thousand-twenty-five)
  * [ServiceNow Accessibility Roadmap](https://www.servicenow.com/accessibility-statement.html#roadmap)
  * [2026 Plans](https://www.servicenow.com/accessibility-statement.html#two-thousand-twenty-six)
  * [2027 Forward-Looking Plans](https://www.servicenow.com/accessibility-statement.html#two-thousand-twenty-seven)
  * [2028 Forward-Looking Plans](https://www.servicenow.com/accessibility-statement.html#two-thousand-twenty-eight)
  * [ServiceNow’s Publications on Accessibility](https://www.servicenow.com/accessibility-statement.html#publications)


We make work, work better for everyone. Accessibility is not an aspiration for us. It’s how we build.
We are firmly committed to achieving WCAG 2.2 Level AA standards across our Platform and Products. Accessibility is embedded in every stage of our Product Development Lifecycle (PDLC), from initial design through delivery.
Our **Accessibility Employee Engagement Panel** , which includes over 200 employees with a diverse range of abilities, helps guide our development. They provide direct feedback early and often, so we can build technology that works in real‑word situations. We also prioritize usability alongside formal accessibility validations, recognizing its critical role in delivering inclusive experiences.
We continuously enhance our Platform and Products—expanding features, optimizing experiences, and strategically planning improvements for future releases.
We also empower our customers to build accessible solutions. Our Platform includes accessibility checkers, best practices, and guidelines so customers can configure and customize their instances while maintaining accessibility.
##  Our Dedicated Accessibility Practice
Our commitment extends to significant investments in our accessibility practice, including a multidiscipline Accessibility Center of Excellence (COE) team. Our COE drives standards and implementation across ServiceNow, ensuring we meet customer expectations while aligning with global practices.
Our applications are designed to support assistive technologies such as NVDA, JAWS, VoiceOver, TalkBack, Dragon, and ZoomText. We also allow for the exclusive use of the keyboard to navigate and operate the product content and functionality. To ensure broad compatibility, we rigorously test across multiple browsers, including Chrome, Safari, and Edge Chromium.
##  Accessibility Conformance Reports (ACRs)
ServiceNow’s [Accessibility Conformance Reports (ACRs)](https://docs.servicenow.com/bundle/accessibility/page/administer/accessibility-508-compliance/concept/available-accessibility-conformance-reports.html) show how our Platform and Products conform to globally recognized accessibility standards like Section 508 of the US Rehabilitation Act, Web Content Accessibility Guidelines (WCAG), and EN 301 549. These reports help our customers evaluate our Platform and Products against their accessibility requirements.
We use the international version of the Voluntary Product Accessibility Template (VPAT), a standardized and commonly used template for creating ACRs developed by the Information and Technology Industry Council, for new reports. Our ACRs are completed after internal assessments and third‑party audits performed by certified accessibility vendors. Exceptions identified during testing are documented with explanatory remarks within our ACRs. Published ACRs are available on our Product Documentation site.
_Note: We continuously enhance our Platform and Products. Published ACRs reflect products at the time of assessment and may not include the latest updates._
Questions: Accessibility_Support@servicenow.com.
##  2025 Accomplishments
In 2025, we released these accessibility features and improvements:
**Voice Input for Now Assist:** Enabled an optional voice input setting for the Now Assist panel, providing a Voice‑to‑Text option utilizing AI to access Now Assist skills.
**Enhanced Keyboard Shortcuts for Next Experience:**
    * **Customized Shortcuts:** Provided users with the ability to leverage 40+ predefined keyboard shortcuts or to design their own at the Admin or User level.
    * **Categorized Shortcuts:** Introduced new keyboard shortcut categories, enhancing users’ ability to quickly locate keyboard shortcuts which significantly improves navigation for keyboard reliant users, including those with mobility impairments.
    * **New Shortcuts:** Released new shortcuts to open/close the Now Assist panel and enable voice input for Now Assist.


  * **Document Services** : Enhanced functionality so users can more easily create and export accessible PDFs directly from records and lists.
  * **Rich Text Editor (TinyMCE) Upgraded for Knowledge and Service Catalog:** Enabled users to identify and resolve accessibility related issues in Knowledge articles or catalog items using the built‑in accessibility checker.
  * **Improved Assistive Technology (AT) Experience:** Resolved potential limitations to ensure more seamless content access, application navigation, and feature utilization for users of Assistive Technology.
  * **Text Adjust Neurodiversity Extension:** Empowered users with neurodivergent conditions (Dyslexia, Autism, ADHD, etc.) to personalize their reading experience. This Chromium‑based extension (available in the ServiceNow Store) allows users to modify webpage UI by changing font families and adjusting letter, word, and paragraph spacing for optimal readability.


  * Added accessibility checkers into more of our builder tools to help customers maintain accessibility compliance when they configure and customize the software.


  * Introduced new capabilities to simplify customizations and improve efficiency.
  * Released new [Gen] AI LLM capabilities to summarize records and pages for simplification and productivity.
  * Increased our volume of available resources, such as additional accessibility of product documentation, demonstrations, and how‑to videos to showcase how our Platform and Products can be customized for users with disabilities.
  * Added a new Communities page for Accessibility ‑ [https://www.servicenow.com/community/accessibility‑a11y/start‑here‑accessibility‑a11y‑resources/ta‑p/3119844](https://www.servicenow.com/community/accessibility-a11y/start-here-accessibility-a11y-resources/ta-p/3119844) .
  * Grew our PAC and incorporated quarterly usability sessions.
  * Embedded additional automated accessibility testing and guardrails in the PDLC (Product Development Lifecycle).
  * Invested in our employees with expanded accessibility champion program, employee panel.
  * Enhanced internal training offerings, including a mandatory accessibility course for all employees; expanded training opportunities through ServiceNow University for Partners and Customers.
  * Released AI Model Accessibility Checker (AIMAC), an open‑source tool developed by the GAAD Foundation. Its purpose is to evaluate and benchmark how effectively coding‑focused Large Language Models (LLMs) generate accessible code.


##  Accessibility Roadmap
##  2026 Plans
_The following initiatives are planned for 2026 but are subject to change based on technical feasibility, customer needs, and business priorities. Plans should not be interpreted as commitments._
Improving the conformance of key Core UI applications.
  * Leveraging AI to interpret and summarize on‑screen content, enabling users to efficiently access information and perform tasks.
  * Simplifying personalization by providing interactive user guidance related to the adoption of OOTB preferences.
  * Enable users to use voice commands to complete their daily tasks.
  * Launch Voice Output Capability to allow text‑to‑speech functionality.
  * Improving Voice Input Capability by adding multilingual support.


  * Provide real‑time guidance via a conversational experience.
  * Expand support for Text Adjust neurodiversity browser extension to additional languages including French Canadian, Spanish, German, and Japanese.


  * Enable orchestrating, tracking, and end‑to‑end automation of accessibility programs.
  * Offering additional themes to improve contrast for people with color‑visual deficiencies or who needs an enhanced contrast.
  * Expanding our PDF accessibility tags support for document conversion to help define document structure and provide logical reading order.


  * Streamlining accessibility user preferences to improve the experience for users with adaptive technology needs.
  * Enabling additional accessibility checkers into our Platform to help customers maintain accessibility compliance when they configure and customize the software.
  * Enhancing our resource library for sales and enablement with more demonstrations, how to videos, and customer success stories.
  * Scaling accessibility usability testing through partnerships and expansion of our employee panel.
  * Embedding accessibility into ServiceNow’s Vibe coding and Build Agent experiences.
  * Enhancing the use of AIMAC Accessibility Checker.
  * Strategically positioning our Platform and Products to adapt and uphold evolving accessibility standards.


  * Introducing more capabilities for Text‑to‑X to simplify customizations and improve efficiency.


_Actual features, timelines, and capabilities may differ based on technical and business considerations._
##  2027 Forward-Looking Plans
These plans are directional and subject to significant change. They reflect current exploration areas and should not be interpreted as commitments or guarantees.
Our 2027 planning includes exploring:
  * Continued work toward higher levels of conformance and addressing high impact defects.
  * POCs for alternative methods of interaction with the Platform, including sign language capabilities.
  * Continue to expand automated accessibility testing coverage, including cognitive accessibility heuristics and documentation accessibility checks.


  * AI‑assisted remediation capabilities to help developers, admins, and creators identify and address accessibility issues.
  * Expanding Voice + Multimodal Interaction capabilities using AI to support users with varied interaction needs.


  * Advancement of our Accessibility Maturity Model.
  * Preparation approaches for future WCAG 3.0 conformance requirements.
  * New assistive methods directly into our platform using AI.
  * Remediation support for custom issues within scanning and testing tooling.
  * Enhanced user onboarding experiences.
  * Neurodiversity support features with UI adaption preferences within our Platform.
  * Additional accessibility checkers in our Platform.
  * Enhanced Text‑to‑X or X‑to‑Text capabilities.
  * Additional training, demonstrations, usability studies, best practices and customer success stories.
  * Enhanced accessibility capabilities in ServiceNow’s Vibe coding and Build Agent experiences.


_These forward‑looking plans reflect our current thinking and are subject to change. Actual features, capabilities, and timelines may differ materially based on technical, market, and business considerations._
##  2028 Forward-Looking Plans
These plans are exploratory and subject to change based on technical feasibility, market conditions, customer priorities, and resource availability. They should not be interpreted as commitments or guarantees.
**Our 2028 planning includes exploring:**
  * Dynamic UI personalization capabilities based on user accessibility preferences.
  * Increase our neurodiverse preferences/features
  * Approaches to support evolving global requirements across WCAG 2.2 AA, EN 301 549, the European Accessibility Act, Section 508, and international regulations.


  * Early piloting of WCAG 3.0 Success Criterion mappings, score‑based models, and outcome‑centric approaches.
  * Continue to expand automated accessibility testing coverage, including cognitive accessibility heuristics and documentation accessibility checks.
  * AI‑driven pattern recognition to detect emerging accessibility issues in customer configurations, custom components, and extensions.
  * Strengthening Text‑to‑X automation to capabilities to generate accessible templates, alt‑text, form labels, and semantic structures.


##  ServiceNow’s Publications on Accessibility
Getting Started with Accessibility at ServiceNow ‑ [https://www.servicenow.com/community/accessibility‑a11y/start‑here‑accessibility‑a11y‑resources/ta‑p/3119844](https://www.servicenow.com/community/accessibility-a11y/start-here-accessibility-a11y-resources/ta-p/3119844)
###  FEATURED RESOURCES
[ Resource Center ](https://www.servicenow.com/resources.html)
###  LEARN MORE
[ Trademarks ](https://www.servicenow.com/trademarks.html)
#### Get the latest ServiceNow updates
Email
Email is not valid
Subscribe
* * *
#####  Company
  * [ About ](https://www.servicenow.com/company.html)
  * [ Careers ](https://careers.servicenow.com/)
  * [ Locations ](https://www.servicenow.com/company/locations.html)
  * [ Partners ](https://www.servicenow.com/partners.html)
  * [ Suppliers ](https://www.servicenow.com/company/supplier.html)
  * [ Investors ](https://www.servicenow.com/company/investor-relations.html)
  * [ Code of ethics ](https://www.servicenow.com/standard/other-documents/code-of-business-conduct-ethics-policy.html)
  * [ Newsroom ](https://newsroom.servicenow.com/overview/default.aspx)
  * [ Blog ](https://www.servicenow.com/blogs.html)
  * [ Workflow magazine: Insights and research ](https://www.servicenow.com/workflow.html)
  * [ Artificial Intelligence ](https://www.servicenow.com/ai.html)


#####  Services and Support
  * [ Services ](https://www.servicenow.com/services/overview.html)
  * [ ServiceNow Support portal ](https://support.servicenow.com/)


#####  Resources
  * [ Customer stories ](https://www.servicenow.com/customers.html)
  * [ ServiceNow AI Research ](https://www.servicenow.com/research/)
  * [ Now on Now ](https://www.servicenow.com/company/how-servicenow-uses-servicenow.html)
  * [ Training and certification ](https://www.servicenow.com/services/training-and-certification.html)
  * [ User community ](https://www.servicenow.com/community/)
  * [ Developer portal ](https://developer.servicenow.com/)
  * [ Product documentation ](https://docs.servicenow.com/)
  * [ Product accessibility ](https://www.servicenow.com/company/accessibility.html)
  * [ Resource library ](https://www.servicenow.com/resources.html)
  * [ What is GenAI ](https://www.servicenow.com/ai/what-is-generative-ai.html)


#####  My Account
  * [ Sign In ](https://account.servicenow.com/sign-in?client_id=0oakzlc2t3W1goPqt0x7&redirect_uri=https%3A%2F%2Fwww.servicenow.com%2Fbin%2Fservicenow%2Fv2%2Ftoken&response_type=token%20id_token&state=https%3A%2F%2Fwww.servicenow.com%2Faccessibility-statement.html&scope=openid&source_id=www&locale=en-us)
  * [ Register ](https://account.servicenow.com/sign-up?client_id=0oakzlc2t3W1goPqt0x7&redirect_uri=https%3A%2F%2Fwww.servicenow.com%2Fbin%2Fservicenow%2Fv2%2Ftoken&response_type=token%20id_token&state=https%3A%2F%2Fwww.servicenow.com%2Faccessibility-statement.html&scope=openid&source_id=www&locale=en-us)


* * *
####  Request info or schedule a demo
[Contact Us](https://www.servicenow.com/contact-us.html)
###  ![ServiceNow logo](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/images/global-nav/images/logo/1024-up.svg) The world works with ServiceNow™
[ ](https://twitter.com/servicenow) [ ](https://www.youtube.com/user/servicenowinc) [ ](https://www.linkedin.com/company/servicenow) [ ](https://www.facebook.com/servicenow) [ ](https://www.instagram.com/servicenow/) [ ](https://www.tiktok.com/@servicenow)
  * United States - Global
Americas
    * [ United States - Global ](https://www.servicenow.com/accessibility-statement.html)
    * [ Brasil - Português ](https://www.servicenow.com/br/accessibility-statement.html)
    * [ Canada - Français ](https://www.servicenow.com/fr-ca/accessibility-statement.html)
    * [ América Latina – Español ](https://www.servicenow.com/latam/accessibility-statement.html)
Asia, Pacific, and Japan
    * [ 日本 - 日本語 ](https://www.servicenow.com/jp/accessibility-statement.html)
    * [ 한국 - 한국어 ](https://www.servicenow.com/kr/accessibility-statement.html)
    * [ Australia/NZ - English ](https://www.servicenow.com/au/accessibility-statement.html)
    * [ India - English ](https://www.servicenow.com/in/accessibility-statement.html)
Europe, Middle East, and Africa
    * [ United Kingdom - English ](https://www.servicenow.com/uk/accessibility-statement.html)
    * [ DACH - Deutsch ](https://www.servicenow.com/de/accessibility-statement.html)
    * [ France - Français ](https://www.servicenow.com/fr/accessibility-statement.html)
    * [ Nederland - Nederlands ](https://www.servicenow.com/nl/accessibility-statement.html)
    * [ España - Español ](https://www.servicenow.com/es/accessibility-statement.html)
    * [ Italia - Italiano ](https://www.servicenow.com/it/accessibility-statement.html)
  * [ Site terms ](https://www.servicenow.com/terms-of-use.html)
  * [ GDPR ](https://www.servicenow.com/company/trust/privacy/gdpr.html)
  * [ Privacy statement ](https://www.servicenow.com/privacy-statement.html)
  * [ Your privacy choices ](https://www.servicenow.com/privacy-preferences.html)
  * [ Cookie policy ](https://www.servicenow.com/cookie-policy.html)
  * [ Cookie preferences ](https://www.servicenow.com/accessibility-statement.html)
  * [ Sitemap ](https://www.servicenow.com/sitemap.html)
  * [ Business continuity ](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/doc-type/public-document/servicenow-business-continuity-faq.pdf)
  * [ Accessibility ](https://www.servicenow.com/accessibility-statement.html)
  * [Website feedback](javascript:void\(0\);)
  * © 2026 ServiceNow. All rights reserved.


[ Contact ](https://www.servicenow.com/contact-us.html) [ Demo ](https://www.servicenow.com/lpdem/demonow-all.html)
We use cookies on this site to improve your browsing experience, analyze individualized usage and website traffic, tailor content to your preferences, and make your interactions with our website more meaningful. To learn more about the cookies we use and how you can change your preferences, please read our [Cookie Policy](https://www.servicenow.com/cookie-policy.html) and visit our Cookie Preference Manager. By clicking “Accept and Proceed,” closing this banner or continuing to browse this site, you consent to the use of cookies.
Accept and Proceed
![](https://id.rlcdn.com/464526.gif)
![](https://bat.bing.com/action/0?ti=150000185&Ver=2&mid=01202792-4a3b-4b36-96e5-78ce000749ed&bo=2&sid=bdde084013ad11f1a28e5b96e01255d6&vid=bdde9e6013ad11f19e4327aec34e57fe&vids=0&msclkid=N&pi=918639831&lg=en-US&sw=1080&sh=600&sc=24&tl=Accessibility%20Statement%20-%20ServiceNow&p=https%3A%2F%2Fwww.servicenow.com%2Faccessibility-statement.html&r=&lt=4556&evt=pageLoad&sv=2&asc=G&cdb=AQAS&rn=485933)
![](https://pt.ispot.tv/v2/TC-8010-2.gif?app=web&type=Visit)![](https://cdn.bizible.com/ipv?_biz_r=&_biz_h=800054037&_biz_u=c8cd2b62188748f19023a5c5b22cefc0&_biz_l=https%3A%2F%2Fwww.servicenow.com%2Faccessibility-statement.html&_biz_t=1772177237854&_biz_i=Accessibility%20Statement%20-%20ServiceNow&_biz_n=10&rnd=184033&cdn_o=a&_biz_z=1772177237855)
